{$apptype CONSOLE}
{$R+,Q+,O-}
{$ASSERTIONS ON}
{$define DEBUG}
{$define FILE_IO}
uses
    Math, Sysutils;

const
    INFINITY = maxint div 2;

    MAX_N = 100;
    MAX_M = MAX_N + 2;
    MAX_Q = 2 * MAX_M;
    MAX_COST = 10000;

type
	TOfficial = record
    	cost : integer;
        deps : array[1..MAX_N] of boolean;
        dead : boolean;
        take : boolean;
    end;

var
	n : integer;
    offs : array[1..MAX_N] of TOfficial;
    timeline : array[1..MAX_N] of integer;
    nAlive : integer;

    m : integer;
    cap : array[1..MAX_M,1..MAX_M] of integer;
    flow : array[1..MAX_M,1..MAX_M] of integer;
    h : array[1..MAX_M] of integer;
    cur : array[1..MAX_M] of integer;
    exc : array[1..MAX_M] of integer;

procedure ReadInput;
var
	i, j, k, q : integer;

begin
{$ifdef FILE_IO}
	reset(input, 'officials.in');
{$endif}	

    read(n);
    assert((n >= 1) and (n <= MAX_N));
    assert(eoln);
    readln;

    fillchar(offs, sizeof(offs), 0);

    for i := 1 to n do begin
    	read(offs[i].cost);
        assert(abs(offs[i].cost) <= MAX_COST);
        assert(not eoln);
        read(k);
        assert((k >= 0) and (k <= MAX_N));
        for j := 1 to k do begin
        	assert(not eoln);
            read(q);
            assert((q >= 1) and (q <= n));
            assert(not offs[i].deps[q]);
            offs[i].deps[q] := true;
        end;
        assert(eoln);
        readln;
    end;
end;

procedure FindDead;
var
	visited : array[1..MAX_N] of boolean;
    ref : array[1..MAX_N] of integer;
    col : array[1..MAX_N] of integer;
    time : integer;
    i, j : integer;

    procedure DFS1(i : integer);
    var
    	j : integer;

    begin
    	if visited[i] then
        	exit;
        visited[i] := true;

        for j := 1 to n do
        	if offs[i].deps[j] then
            	DFS1(j);

        inc(time);
        ref[time] := i;
    end;

    function DFS2(i, whichcol : integer) : integer;
    var
    	j : integer;

    begin
    	result := 0;
    	if col[i] <> 0 then
        	exit;
        col[i] := whichcol;
        inc(result);

        for j := 1 to n do
        	if offs[j].deps[i] then
            	inc(result, DFS2(j, whichcol));
    end;

    procedure DFS3(i : integer);
    var
    	j : integer;

    begin
    	offs[i].dead := true;
    	for j := 1 to n do
        	if offs[j].deps[i] and not offs[j].dead then
            	DFS3(j);
    end;

begin
	fillchar(visited, sizeof(visited), 0);
    time := 0;
    for i := 1 to n do
		DFS1(i);

	fillchar(col, sizeof(col), 0);
    for i := n downto 1 do
		if DFS2(ref[i], i) > 1 then begin
{$ifdef DEBUG}
        	writeln('component at ', ref[i], ' is dead');
{$endif}
        	for j := 1 to n do
            	if col[j] = i then
                	offs[j].dead := true;
        end;

	for i := 1 to n do
    	if offs[i].deps[i] then begin
{$ifdef DEBUG}
        	writeln('official ', i, ' is reflexively dead');
{$endif}
			offs[i].dead := true;
        end;

    for i := 1 to n do
    	if offs[i].dead then
        	DFS3(i);

{$ifdef DEBUG}
    write('dead officials:');
    for i := 1 to n do
    	if offs[i].dead then
        	write(' ', i);
    writeln;
{$endif}
end;

procedure BuildTimeline;
var
	visited : array[1..MAX_N] of boolean;
    i : integer;

    procedure DFS(i : integer);
    var
    	j : integer;

    begin
    	if visited[i] or offs[i].dead then
        	exit;
        visited[i] := true;

        for j := 1 to n do
        	if offs[i].deps[j] then
            	DFS(j);

        inc(nAlive);
        timeline[nAlive] := i;
    end;

begin
	fillchar(visited, sizeof(visited), 0);
    nAlive := 0;
    for i := 1 to n do
		DFS(i);
{$ifdef DEBUG}
    write('timeline:');
    for i := 1 to nAlive do
		write(' ', timeline[i]);
    writeln;
{$endif}
end;

procedure FindMaxFlow(s, t : integer);
var
	i : integer;

    q : array[1..MAX_Q] of integer;
    head, tail : integer;
    inq : array[1..MAX_M] of boolean;

    procedure QInit;
    begin
    	head := 1;
        tail := 1;
        fillchar(inq, sizeof(inq), false);
    end;

    function IsQEmpty : boolean;
    begin
    	IsQEmpty := tail = head;
    end;

    function QPop : integer;
    begin
    	result := q[tail];
        inq[result] := false;
        inc(tail);
        if tail > MAX_Q then
        	tail := 1;
    end;

    procedure QPush(value : integer);
    begin
    	q[head] := value;
        inq[value] := true;
        inc(head);
        if head > MAX_Q then
        	head := 1;
    end;

    procedure Lift(i : integer);
    var
    	newh : integer;
        j : integer;

    begin
    	newh := infinity;
    	for j := 1 to m do
        	if flow[i,j] < cap[i,j] then
            	newh := min(newh, h[j]);
        h[i] := newh + 1;
{$ifdef DEBUG}
		writeln('lift ', i, ' upto ', h[i]);
{$endif}
    end;

    procedure Push(i, j : integer; eps : integer);
    begin
{$ifdef DEBUG}
		writeln('push ', eps, ' via ', i, '->' , j);
{$endif}
        if not inq[j] and (eps > 0) and (j <> s) and (j <> t) then
            QPush(j);
        dec(exc[i], eps);
        inc(exc[j], eps);
        inc(flow[i,j], eps);
        dec(flow[j,i], eps);
        inc(cur[i]);
    end;

    procedure Discharge(i : integer);
    var
    	j : integer;
        eps : integer;

    begin
{$ifdef DEBUG}
		writeln('discharge ', i, ' with exc = ', exc[i]);
{$endif}
		repeat
        	if exc[i] = 0 then
            	exit;

            j := cur[i];
            if j > m then begin
           		Lift(i);
                cur[i] := 1;
                continue;
            end;

            if (flow[i,j] < cap[i,j]) and (h[i] = h[j] + 1) then begin
            	eps := min(exc[i], cap[i,j] - flow[i,j]);
                Push(i, j, eps);
            end;
            inc(cur[i]);
        until false;
    end;

begin
    fillchar(h, sizeof(h), 0);
    h[s] := m;
    QInit;
    for i := 1 to m do
    	if cap[s,i] > 0 then
	    	Push(s, i, cap[s,i]);

    for i := 1 to m do
    	cur[i] := 1;

    while not IsQEmpty do begin
    	i := QPop;
        Discharge(i);
    end;
end;

procedure BuildNetwork;
var
	i, j : integer;

begin
	m := n + 2;
    fillchar(cap, sizeof(cap), 0);
    for i := 1 to n do if not offs[i].dead then
    	for j := 1 to n do if not offs[j].dead then
        	if offs[i].deps[j] then
            	cap[i,j] := infinity;

    for i := 1 to n do
    	if not offs[i].dead then
            if offs[i].cost >= 0 then begin
                cap[n+1,i] := offs[i].cost;
            end else begin
                cap[i,n+2] := -offs[i].cost;
            end;
end;

procedure PrintFlow;
var
	i, j : integer;

begin
	for i := 1 to m do begin
    	for j := 1 to m do
        	write(flow[i,j]:4);
		writeln;
    end;
end;

procedure BuildAnswer;
var
	visited : array[1..MAX_M] of boolean;
    i : integer;

    procedure DFS(i : integer);
    var
    	j : integer;

    begin
    	if visited[i] then
        	exit;
        visited[i] := true;

    	for j := 1 to m do
        	if flow[i,j] < cap[i,j] then
            	DFS(j);
    end;

begin
	fillchar(visited, sizeof(visited), false);
    DFS(n + 1);
    for i := 1 to n do
    	offs[i].take := visited[i];
end;

procedure Solve;
begin
	FindDead;
    BuildTimeline;
    BuildNetwork;
    FindMaxFlow(n + 1, n + 2);
{$ifdef DEBUG}
    PrintFlow;
{$endif}
    BuildAnswer;
end;

procedure WriteOutput;
var
	i, count : integer;

begin
{$ifdef FILE_IO}
	rewrite(output, 'officials.out');
{$endif}
	count := 0;
    for i := 1 to n do
    	if offs[i].take then
        	inc(count);
    writeln(count);
    for i := 1 to nAlive do
    	if offs[timeline[i]].take then
        	write(timeline[i], ' ');
    writeln;
end;

begin
    ReadInput;
    Solve;
    WriteOutput;
end.

